@@ -30,6 +30,7 @@ KEYWORDS_TO_NOT_FLATTEN = set(["gpg_signature", "content"])
 
 LEGACY_PYPI = 'https://pypi.python.org/'
 WAREHOUSE = 'https://upload.pypi.org/'
+OLD_WAREHOUSE = 'https://upload.pypi.io/'
 
 
 class Repository(object):
@@ -158,7 +159,7 @@ class Repository(object):
     def package_is_uploaded(self, package, bypass_cache=False):
         # NOTE(sigmavirus24): Not all indices are PyPI and pypi.io doesn't
         # have a similar interface for finding the package versions.
-        if not self.url.startswith((LEGACY_PYPI, WAREHOUSE)):
+        if not self.url.startswith((LEGACY_PYPI, WAREHOUSE, OLD_WAREHOUSE)):
             return False
 
         safe_name = package.safe_name
